﻿* Encoding: UTF-8.
*******************************************************************************************************************************************************************************************************************.
************************************************** GENERACIÓN DE TABULADOS - ENCUESTA ESTRUCTURAL EMPRESARIAL 2020 ************************************************************.
*******************************************************************************************************************************************************************************************************************.

*INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC).
*FUENTE: Encuesta Estructural Empresarial 2020.
*RESPONSABLE: Unidad de Gestión de Estadísticas Estructurales (GESE).
*Fecha de elaboración: Abril 2022.
*Fecha de última actualización: 08/04/2022

*Estimado Usuario. Por favor en el disco C: de su computadora, crear una carpeta llamada "Tabulados Estructural", y coloque la base de datos de la encuesta.
*En esta carpeta se exportarán los resultados de los tabulados. 

****TABULADOS 2020***.
GET FILE ='C:\Tabulados Estructural\2020_ESTRUCTURAL_EMPRESARIAL_BDD.sav'.

*CUADRO 8. INDICADORES DE RELACIÓN.

COMPUTE N=1.
VARIABLE LABELS N 'Nacional'.
VARIABLE LEVEL N (NOMINAL).
EXECUTE.

SAVE OUTFILE ='C:\Tabulados Estructural\2020_ESTRUCTURAL_EMPRESARIAL_BDD.sav'.

*GENERACIÓN DE INDICADORES.
*8-1.
GET FILE ='C:\Tabulados Estructural\2020_ESTRUCTURAL_EMPRESARIAL_BDD.sav'.
weight by f_exp.
USE ALL.
COMPUTE filter_$=(prodtota>0 and totalpeoc>0).
FILTER BY filter_$.
EXECUTE.

AGGREGATE
  /OUTFILE='C:\Tabulados Estructural\C8-1.sav'
  /BREAK=N
  /prodtota_sum 'Producción total empresarial'=SUM(prodtota)
  /totalpeoc_sum 'Personal ocupado total empresarial'=SUM(totalpeoc).

GET FILE='C:\Tabulados Estructural\C8-1.sav'.
execute.

compute prodpo=prodtota_sum/totalpeoc_sum.
variable labels prodpo 'Producción empresarial por persona ocupada'.
execute.

SAVE OUTFILE='C:\Tabulados Estructural\C8-1.sav'.

*8-2.
GET FILE ='C:\Tabulados Estructural\2020_ESTRUCTURAL_EMPRESARIAL_BDD.sav'.
weight by f_exp.
USE ALL.
COMPUTE filter_$=(prodtota>0 and hanuales>0).
FILTER BY filter_$.
EXECUTE.

AGGREGATE
  /OUTFILE='C:\Tabulados Estructural\C8-2.sav'
  /BREAK=N
  /prodtota_sum 'Producción total empresarial'=SUM(prodtota)
  /hanuales_sum 'Horas totales anuales'=SUM(hanuales).

GET FILE='C:\Tabulados Estructural\C8-2.sav'.
execute.

compute prodh=prodtota_sum/hanuales_sum.
variable labels prodh 'Producción empresarial por hora trabajada'.
execute.

SAVE OUTFILE ='C:\Tabulados Estructural\C8-2.sav'.

*8-3.
GET FILE ='C:\Tabulados Estructural\2020_ESTRUCTURAL_EMPRESARIAL_BDD.sav'.
weight by f_exp.
USE ALL.
COMPUTE filter_$=(valag>0 and totalpeoc>0).
FILTER BY filter_$.
EXECUTE.

AGGREGATE
  /OUTFILE='C:\Tabulados Estructural\C8-3.sav'
  /BREAK=N
/valag_sum 'Valor agregado total empresarial'=SUM(valag)
/totalpeoc_sum 'Personal ocupado total empresarial'=SUM(totalpeoc).

GET FILE='C:\Tabulados Estructural\C8-3.sav'.
execute.

compute valagpo=valag_sum/totalpeoc_sum.
variable labels valagpo 'Valor agregado empresarial por persona ocupada'.
execute.

SAVE OUTFILE ='C:\Tabulados Estructural\C8-3.sav'.

*8-4.
GET FILE ='C:\Tabulados Estructural\2020_ESTRUCTURAL_EMPRESARIAL_BDD.sav'.
weight by f_exp.
USE ALL.
COMPUTE filter_$=(valag>0 and hanuales>0).
FILTER BY filter_$.
EXECUTE.

AGGREGATE
  /OUTFILE='C:\Tabulados Estructural\C8-4.sav'
  /BREAK=N
/valag_sum 'Valor agregado total empresarial'=SUM(valag)
/hanuales_sum 'Horas totales anuales'=SUM(hanuales).

GET FILE='C:\Tabulados Estructural\C8-4.sav'.
execute.

compute valagh=valag_sum/hanuales_sum.
variable labels valagh 'Valor agregado empresarial por hora trabajada'.
execute.

SAVE OUTFILE ='C:\Tabulados Estructural\C8-4.sav'.

*Unificación de indicadores.
GET FILE = 'C:\Tabulados Estructural\C8-1.sav'.
DELETE VARIABLES prodtota_sum totalpeoc_sum.

MATCH FILES /FILE=*
  /TABLE='C:\Tabulados Estructural\C8-2.sav'
  /RENAME (hanuales_sum prodtota_sum = d0 d1) 
  /BY N
  /DROP= d0 d1.
EXECUTE.

MATCH FILES /FILE=*
  /TABLE='C:\Tabulados Estructural\C8-3.sav'
  /RENAME (totalpeoc_sum valag_sum = d0 d1) 
  /BY N
  /DROP= d0 d1.
EXECUTE.

MATCH FILES /FILE=*
  /TABLE='C:\Tabulados Estructural\C8-4.sav'
  /RENAME (hanuales_sum valag_sum = d0 d1) 
  /BY N
  /DROP= d0 d1.
EXECUTE.

SAVE OUTFILE = 'C:\Tabulados Estructural\C8S.sav'.

*C8-SECCIÓN.
TABLES
  /OBSERVATION =prodpo prodh valagpo valagh
  /FORMAT BLANK MISSING('.')
 /TABLE=N BY (prodpo+prodh+valagpo+valagh)
 /STATISTICS SUM (' ')
 /TITLE  'CUADRO No. 8-NACIONAL'
           'PRINCIPALES INDICADORES DE RELACIÓN, A NIVEL NACIONAL'
           '(VALORES EN DÓLARES)'
 /CAPTION  'INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - ENCUESTA ESTRUCTURAL EMPRESARIAL 2020'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados Estructural\2020_TABULADOS_NAC'
     OPERATION=CREATESHEET  SHEET='C8-N'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.
